==> dif-database-repository-2.1.9-1-20151124.173937-3-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/CustomMessages.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * CustomMessages
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class CustomMessages extends AbstractBeanAttributes implements java.io.Serializable {

    /** CustomMessages attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** messageId column */
        public static final String MESSAGEID = "messageId";
        /** message column */
        public static final String MESSAGE = "message";
        /** entityId column */
        public static final String ENTITYID = "entityId";
        /** language column */
        public static final String LANGUAGE = "language";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("messageId");
            list.add("message");
            list.add("entityId");
            list.add("language");

            return list;
        }
    }

    /** CustomMessages FK class */
    public static class FK {
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("messageId".equalsIgnoreCase(attributeName))
            return messageId;
        if ("message".equalsIgnoreCase(attributeName))
            return message;
        if ("entityId".equalsIgnoreCase(attributeName))
            return entityId;
        if ("language".equalsIgnoreCase(attributeName))
            return language;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("messageId".equalsIgnoreCase(attributeName))
            messageId = (String)attributeValue;
        if ("message".equalsIgnoreCase(attributeName))
            message = (String)attributeValue;
        if ("entityId".equalsIgnoreCase(attributeName))
            entityId = (String)attributeValue;
        if ("language".equalsIgnoreCase(attributeName))
            language = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** messageId private attribute */
    private String messageId;

    /** message private attribute */
    private String message;

    /** entityId private attribute */
    private String entityId;

    /** language private attribute */
    private String language;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public CustomMessages() {
    }

	/** 
	 * minimal constructor
	 *
     * @param messageId
     * @param message
     * @param entityId
    }
	 */
    public CustomMessages(String messageId, String message, String entityId) {
        this.messageId = messageId;
        this.message = message;
        this.entityId = entityId;
    }

    /**
     * full constructor
	 *
     * @param messageId
     * @param message
     * @param entityId
     * @param language
     */
    public CustomMessages(String messageId, String message, String entityId, String language) {
        this.messageId = messageId;
        this.message = message;
        this.entityId = entityId;
        this.language = language;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return CustomMessages modified instance
     */
    public CustomMessages setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * messageId getter method
     *
     * @return messageId method
     */
    public String getMessageId() {
        return this.messageId;
    }
    
    /**       
     * messageId setter method
     *
     * @param messageId
     *
     * @return CustomMessages modified instance
     */
    public CustomMessages setMessageId(String messageId) {
        this.messageId = messageId;
        
        return this;
    }
    /**       
     * message getter method
     *
     * @return message method
     */
    public String getMessage() {
        return this.message;
    }
    
    /**       
     * message setter method
     *
     * @param message
     *
     * @return CustomMessages modified instance
     */
    public CustomMessages setMessage(String message) {
        this.message = message;
        
        return this;
    }
    /**       
     * entityId getter method
     *
     * @return entityId method
     */
    public String getEntityId() {
        return this.entityId;
    }
    
    /**       
     * entityId setter method
     *
     * @param entityId
     *
     * @return CustomMessages modified instance
     */
    public CustomMessages setEntityId(String entityId) {
        this.entityId = entityId;
        
        return this;
    }
    /**       
     * language getter method
     *
     * @return language method
     */
    public String getLanguage() {
        return this.language;
    }
    
    /**       
     * language setter method
     *
     * @param language
     *
     * @return CustomMessages modified instance
     */
    public CustomMessages setLanguage(String language) {
        this.language = language;
        
        return this;
    }

    /**
     * Creates a String representation of the CustomMessages object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("messageId").append("='").append(getMessageId()).append("' ");			
        buffer.append("message").append("='").append(getMessage()).append("' ");			
        buffer.append("entityId").append("='").append(getEntityId()).append("' ");			
        buffer.append("language").append("='").append(getLanguage()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the CustomMessages object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(CustomMessages other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("messageId".equalsIgnoreCase(attributeName))
        	this.messageId = attributeValue;

        if ("message".equalsIgnoreCase(attributeName))
        	this.message = attributeValue;

        if ("entityId".equalsIgnoreCase(attributeName))
        	this.entityId = attributeValue;

        if ("language".equalsIgnoreCase(attributeName))
        	this.language = attributeValue;

    }


}

==> dif-database-repository-2.1.9-12-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/CustomMessages.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * CustomMessages Generated on ORM Generator DIF build process for the Model layer
 */
@SuppressWarnings("serial")
public class CustomMessages extends AbstractBeanAttributes implements java.io.Serializable {

    /** CustomMessages attributes enumeration */
    public static class Fields {

        /** id column */
        public static final String ID = "id";
        /** messageId column */
        public static final String MESSAGEID = "messageId";
        /** message column */
        public static final String MESSAGE = "message";
        /** entityId column */
        public static final String ENTITYID = "entityId";
        /** language column */
        public static final String LANGUAGE = "language";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("messageId");
            list.add("message");
            list.add("entityId");
            list.add("language");

            return list;
        }
    }

    /** CustomMessages FK class */
    public static class FK {
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName)
    {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("messageId".equalsIgnoreCase(attributeName))
            return messageId;
        if ("message".equalsIgnoreCase(attributeName))
            return message;
        if ("entityId".equalsIgnoreCase(attributeName))
            return entityId;
        if ("language".equalsIgnoreCase(attributeName))
            return language;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue)
    {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long) attributeValue;
        if ("messageId".equalsIgnoreCase(attributeName))
            messageId = (String) attributeValue;
        if ("message".equalsIgnoreCase(attributeName))
            message = (String) attributeValue;
        if ("entityId".equalsIgnoreCase(attributeName))
            entityId = (String) attributeValue;
        if ("language".equalsIgnoreCase(attributeName))
            language = (String) attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** messageId private attribute */
    private String messageId;

    /** message private attribute */
    private String message;

    /** entityId private attribute */
    private String entityId;

    /** language private attribute */
    private String language;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    public synchronized static List<String> getPKFieldList()
    {
        if (pkFieldList == null)
        {
            pkFieldList = new ArrayList<String>();
            pkFieldList.add("id");
        }

        return pkFieldList;
    }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
    public static String getPKFieldListAsString()
    {
        StringBuffer buffer = new StringBuffer();

        for (int i = 0; i < getPKFieldList().size(); i++)
        {
            if (i != 0)
                buffer.append(",");

            buffer.append(getPKFieldList().get(i));
        }

        return buffer.toString();
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
    @Override
    public String getAttributeAsString(String attributeName)
    {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else
        {
            return value.toString().trim();
        }
    }

    // Constructors

    /**
     * default constructor
     */
    public CustomMessages()
    {}

    /**
     * minimal constructor
     *
     * @param messageId
     * @param message
     * @param entityId
     *            }
     */
    public CustomMessages(String messageId, String message, String entityId)
    {
        this.messageId = messageId;
        this.message = message;
        this.entityId = entityId;
    }

    /**
     * full constructor
     *
     * @param messageId
     * @param message
     * @param entityId
     * @param language
     */
    public CustomMessages(String messageId, String message, String entityId, String language)
    {
        this.messageId = messageId;
        this.message = message;
        this.entityId = entityId;
        this.language = language;
    }

    // Property accessors

    /**
     * id getter method
     *
     * @return id method
     */
    public Long getId()
    {
        return this.id;
    }

    /**
     * id setter method
     *
     * @param id
     * @return CustomMessages modified instance
     */
    public CustomMessages setId(Long id)
    {
        this.id = id;

        return this;
    }

    /**
     * messageId getter method
     *
     * @return messageId method
     */
    public String getMessageId()
    {
        return this.messageId;
    }

    /**
     * messageId setter method
     *
     * @param messageId
     * @return CustomMessages modified instance
     */
    public CustomMessages setMessageId(String messageId)
    {
        this.messageId = messageId;

        return this;
    }

    /**
     * message getter method
     *
     * @return message method
     */
    public String getMessage()
    {
        return this.message;
    }

    /**
     * message setter method
     *
     * @param message
     * @return CustomMessages modified instance
     */
    public CustomMessages setMessage(String message)
    {
        this.message = message;

        return this;
    }

    /**
     * entityId getter method
     *
     * @return entityId method
     */
    public String getEntityId()
    {
        return this.entityId;
    }

    /**
     * entityId setter method
     *
     * @param entityId
     * @return CustomMessages modified instance
     */
    public CustomMessages setEntityId(String entityId)
    {
        this.entityId = entityId;

        return this;
    }

    /**
     * language getter method
     *
     * @return language method
     */
    public String getLanguage()
    {
        return this.language;
    }

    /**
     * language setter method
     *
     * @param language
     * @return CustomMessages modified instance
     */
    public CustomMessages setLanguage(String language)
    {
        this.language = language;

        return this;
    }

    /**
     * Creates a String representation of the CustomMessages object
     *
     * @return the compiled String
     */
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");
        buffer.append("messageId").append("='").append(getMessageId()).append("' ");
        buffer.append("message").append("='").append(getMessage()).append("' ");
        buffer.append("entityId").append("='").append(getEntityId()).append("' ");
        buffer.append("language").append("='").append(getLanguage()).append("' ");
        buffer.append("]");

        return buffer.toString();
    }

    /**
     * Compares the String representation of the CustomMessages object
     *
     * @param other
     *            The object to compare to
     * @return true of the objects are equal
     */
    public boolean equals(CustomMessages other)
    {
        return this.toString().equals(other.toString());
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue)
    {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("messageId".equalsIgnoreCase(attributeName))
            this.messageId = attributeValue;

        if ("message".equalsIgnoreCase(attributeName))
            this.message = attributeValue;

        if ("entityId".equalsIgnoreCase(attributeName))
            this.entityId = attributeValue;

        if ("language".equalsIgnoreCase(attributeName))
            this.language = attributeValue;

    }

}
